#!/bin/bash

# Build 48k speech files

# $Id: 48k.sh,v 1.3 2018/11/22 22:30:48 pkabal Exp $

FileList="FileList.txt"
TextFile="HarvardList.dat"

DirI="../48k-Orig/"
DirO="../48k/"
DBID="48k"

#==========
# ProcFile $File

function ProcFile ()
{
  local File
  local FileI
  local FileO
  local Dir
  local offs

  File=$1
  FileI="${DirI}${File%.wav}.au" # Change .wav to .au
  FileO="${DirO}${File}"

# Create the subdirectory for the output file (example "../48k/CA")
# See linuxgazette.net/18/bash.html
  Dir=${FileO%/*}     # Erase the shortest match to /* from the end
  mkdir -p $Dir

# Get the normalized mean offset value (7th line of CompAudio output)
  GenOffs "$FileI"  # Returns $offs

# Generate the info strings
  GenInfoString "$FileI" "$TextFile" "$DBID"

# For the 48k files, use the date of the input files
# Get the date from the second or third line of InfoAudio output
# "... 131444 (2.738 s)  1997/04/14 17:15:37 UTC"
  FileDate=`InfoAudio -i1 "$FileI" | sed -n '2,3 s/.*s) *\(.*\)$/\1/p'`
  if [ "$FileDate" = "" ]; then
    echo "Error: no date information found" 1>&2
    exit 1
  fi
  FileDate=`date -d "$FileDate" '+%Y-%m-%d %H:%M:%S UTC'` # Standard form
  InfoDate="date: $FileDate"

# Generate the wave file (mean cancellation and info fields)
  CopyAudio "$FileI" -cA "A$offs" \
  -I "" -I "$InfoDate" -I "$InfoTitle" -I "$InfoDB" -I "$InfoID" \
  -I "$InfoSpkr" -I "$InfoText" -I "$InfoRecCond" \
  -D integer16 "$FileO"
  touch -r "$FileI" "$FileO"   # Set the output file date

# Print file information
  echo ""
  InfoAudio -i5 "$FileO"
}

#==========
function GenOffs ()
{
# Get the normalized offset value

  local FileI
  local mean
  local rmean

  FileI=$1

# 7th line of CompAudio output has mean
# "...Mean = 10.068 (0.03072%)" => mean="10.068", rmean=10, offs=-0.0003...
# Use the mean value rather than the percent since it has more precision
  mean=`CompAudio "$FileI" | sed -n '7s/.*Mean = \(.*\) .*/\1/p'`

# Use an integer offset, so integer data values are shifted by the offset
  rmean=`printf "%.0f" $mean`       # Round to integer

# Convert to a normalized offset which is a multiple of 0.000030517578125
  offs=`echo "$rmean / -32768" | bc -l`
  offs=`printf %+.16g $offs`        # Add + sign if positive
}

# Load function
. GenInfo.sh

#===========
# Loop over files
exec < $FileList

while read File
do
  ProcFile $File
done
