#!/bin/bash

# Build 8k-G712 speech files

# $Id: 8k-G712.sh,v 1.1 2018/11/22 22:31:34 pkabal Exp $

FileList="FileList.txt"
TextFile="HarvardList.dat"

DirI="../48k/"
DirO="../8k-G712/"
DBID="8k-G712"

LPx3="../Filters/STL_LPx3_FIR.cof"
G712="../Filters/STL_G712_IIR_16k.cof"

Proc="Filtered and subsampled 6:1"
Filt="ITU-T G.191 Software Tools Library
7 kHz lowpass (168 coefficients at 48 kHz), file: STL_LPx3_FIR.cof
G.712 filter (IIR 4 sections at 16 kHz), file: STL_G712_IIR_16k.cof"

#==========
function ProcFile ()
{
  local File
  local FileI
  local FileO
  local Dir
  local FileDate
  local InfoDate
  local InfoProc
  local InfoFile

  File=$1
  FileI="${DirI}${File}"
  FileO="${DirO}${File}"

# Create the subdirectory for the output file (example "../8k-G712/CA")
# See linuxgazette.net/18/bash.html
  Dir=${FileO%/*}     # Erase the shortest match to /* from the end
  mkdir -p $Dir

# Generate the info strings
  GenInfoString "$FileI" "$TextFile" "$DBID"

# Date / processing / filtering info strings
  FileDate=`date -u '+%Y-%m-%d %H:%M:%S UTC'`
  InfoDate="date: $FileDate"
  InfoProc="processing: $Proc"
  InfoFilt="filter: $Filt"

# Filter: 168 taps, symmetric FIR, delay 83.5 samples at 48 kHz
#   - Filter offset is 83 samples, leaving a delay of 0.5 samples at 48 kHz
#   - Nsub=3, number of samples is floor(Nin/Nsub) at 16 kHz
  FiltAudio -f "$LPx3" -i 1/3 "$FileI" -D float64 temp.wav
# IIR filter at 16 kHz, subsampled
#   - Nsub=2, number of samples is floor(Nin/Nsub) at 8 kHz
  FiltAudio -f "$G712" -i 1/2 temp.wav \
 -I "" -I "$InfoDate" -I "$InfoTitle" -I "$InfoDB" -I "$InfoID" \
 -I "$InfoSpkr" -I "$InfoText" -I "$InfoRecCond" \
 -I "$InfoProc" -I "$InfoFilt" \
 -D integer16 "$FileO"
  rm -f temp.wav

# Print file information
  echo ""
  InfoAudio -i5 "$FileO"
}

# Load function
. GenInfo.sh

#===========
# Loop over files
exec < $FileList

while read File
do
  ProcFile $File
done
